@@ -9,8 +9,11 @@ cleancdfname <- function(cdfname, addcdf=TRUE) {
                 stop(paste("invalid CDF name:", cdfname))
   if ( nchar(cdfname)[1] == 0 )
                stop("supplied cdf name has zero length")
-
-  data("mapCdfName", package="affy")
+  mapCdfName <- NULL # To appease R CMD check
+  mapCdfName <- local({
+      data("mapCdfName", package="affy", envir=environment())
+      get("mapCdfName")
+  })
   i <- match(cdfname, mapCdfName$inCDF)
   if (is.na(i)) {
     tmp <- tolower(cdfname) #make lower case
